(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common'), require('rxjs/BehaviorSubject')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', '@angular/common', 'rxjs/BehaviorSubject'], factory) :
	(factory((global['ng4-tree'] = {}),global._angular_core,global._angular_common,global.rxjs_BehaviorSubject));
}(this, (function (exports,_angular_core,_angular_common,rxjs_BehaviorSubject) { 'use strict';

var TreeDataService = (function () {
    function TreeDataService() {
        this.nodeItem = new rxjs_BehaviorSubject.BehaviorSubject({});
        this.nodeItemEmitter = this.nodeItem.asObservable();
    }
    /**
     * @param {?} item
     * @return {?}
     */
    TreeDataService.prototype.setNodeItem = function (item) {
        this.nodeItem.next(item);
    };
    return TreeDataService;
}());
TreeDataService.decorators = [
    { type: _angular_core.Injectable },
];
/**
 * @nocollapse
 */
TreeDataService.ctorParameters = function () { return []; };

var TreeComponent = (function () {
    /**
     * @param {?} treeDataService
     */
    function TreeComponent(treeDataService) {
        var _this = this;
        this.treeDataService = treeDataService;
        this.click = new _angular_core.EventEmitter();
        this.formatDataList = [];
        this.treeDataService.nodeItemEmitter.subscribe(function (item) {
            _this.click.emit(item);
        });
    }
    Object.defineProperty(TreeComponent.prototype, "data", {
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            if (value.length > 0) {
                this.formatData(value);
            }
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @param {?} data
     * @return {?}
     */
    TreeComponent.prototype.formatData = function (data) {
        var /** @type {?} */ dataList = [];
        for (var /** @type {?} */ i = 0; i < data.length; i++) {
            var /** @type {?} */ subList = [];
            for (var /** @type {?} */ j = 0; j < data.length; j++) {
                if (data[i]['locationGroupID'] === data[j]['parentGroup']) {
                    subList.push(data[j]);
                }
            }
            data[i]['subs'] = subList;
            dataList.push(data[i]);
        }
        this.formatDataList.push(dataList[0]);
    };
    /**
     * @return {?}
     */
    TreeComponent.prototype.ngOnInit = function () { };
    return TreeComponent;
}());
TreeComponent.decorators = [
    { type: _angular_core.Component, args: [{
                selector: 'ng4-tree-component',
                template: "<ng-template ngFor let-item [ngForOf]=\"formatDataList\"> <node-component [item]=\"item\" [type]=\"group\"></node-component> </ng-template> "
            },] },
];
/**
 * @nocollapse
 */
TreeComponent.ctorParameters = function () { return [
    { type: TreeDataService, },
]; };
TreeComponent.propDecorators = {
    'click': [{ type: _angular_core.Output },],
    'data': [{ type: _angular_core.Input },],
};

var NodeComponent = (function () {
    /**
     * @param {?} treeDataService
     */
    function NodeComponent(treeDataService) {
        this.treeDataService = treeDataService;
        this.isExpanded = false;
    }
    /**
     * @return {?}
     */
    NodeComponent.prototype.ngOnInit = function () { };
    /**
     * @param {?} event
     * @return {?}
     */
    NodeComponent.prototype.itemClick = function (event) {
        console.log('SELECTED NODE ITEM', this.item);
        this.treeDataService.setNodeItem(this.item);
        this.toggle();
    };
    /**
     * @return {?}
     */
    NodeComponent.prototype.toggle = function () {
        this.isExpanded = !this.isExpanded;
        console.log(this.isExpanded + ' ' + this.item.name);
    };
    return NodeComponent;
}());
NodeComponent.decorators = [
    { type: _angular_core.Component, args: [{
                selector: 'node-component',
                template: "<!-- [style.list-style-image]=\"type == 'location' ? 'url(assets/group.png)' : 'url(assets/location.png)'\" --> <li (click)=\"itemClick($event)\"> <i [ngClass]=\"type == 'location' ? 'fa fa-map-marker' : 'fa fa-users'\" aria-hidden=\"true\"></i>&nbsp;&nbsp;{{item.name}} <div class=\"icon-align\" *ngIf=\"type == 'group' && item.locations.length > 0\"> <i [ngClass]=\"isExpanded ? 'fa fa-angle-down' : 'fa fa-angle-right'\" aria-hidden=\"true\" (click)=\"toggle()\"></i> </div> <div class=\"icon-align\" *ngIf=\"item.parentGroup == null && item.name == 'All Groups'\"> <i class=\"fa fa-plus-circle\" aria-hidden=\"true\"></i> <i class=\"fa fa-pencil\" aria-hidden=\"true\"></i> <i class=\"fa fa-trash\" aria-hidden=\"true\"></i> </div> <div *ngIf=\"isExpanded || (item.parentGroup == null && item.name == 'All Groups')\"> <ul *ngIf=\"item.locations\" (click)=\"$event.stopPropagation()\"> <ng-template ngFor let-locationitem [ngForOf]=\"item.locations\"> <node-component [item]=\"locationitem\" [type]=\"'location'\"></node-component> </ng-template> </ul> </div> <ul *ngIf=\"item.subs\" (click)=\"$event.stopPropagation()\"> <ng-template ngFor let-subitem [ngForOf]=\"item.subs\"> <node-component [item]=\"subitem\" [type]=\"'group'\"></node-component> </ng-template> </ul> </li> ",
                styles: ["li { list-style-type: none; cursor: pointer; } .icon-align { float: right; } "]
            },] },
];
/**
 * @nocollapse
 */
NodeComponent.ctorParameters = function () { return [
    { type: TreeDataService, },
]; };
NodeComponent.propDecorators = {
    'item': [{ type: _angular_core.Input },],
    'type': [{ type: _angular_core.Input },],
};

var Ng4TreeModule = (function () {
    function Ng4TreeModule() {
    }
    /**
     * @return {?}
     */
    Ng4TreeModule.forRoot = function () {
        return {
            ngModule: Ng4TreeModule,
        };
    };
    return Ng4TreeModule;
}());
Ng4TreeModule.decorators = [
    { type: _angular_core.NgModule, args: [{
                imports: [
                    _angular_common.CommonModule
                ],
                declarations: [
                    TreeComponent,
                    NodeComponent
                ],
                providers: [
                    TreeDataService
                ],
                exports: [
                    TreeComponent,
                    NodeComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
Ng4TreeModule.ctorParameters = function () { return []; };

exports.Ng4TreeModule = Ng4TreeModule;
exports.TreeComponent = TreeComponent;
exports.NodeComponent = NodeComponent;

Object.defineProperty(exports, '__esModule', { value: true });

})));
